@@ -7,7 +7,9 @@ import jsonpath_ng as jsonpath
 
 def make_context(url, content_type, content):
   """Choose the right context based on the content type."""
-  if content_type == 'application/json':
+  # Heuristic to detect JSON mime-type.
+  # [1] https://www.iana.org/assignments/media-types/media-types.xhtml
+  if 'json' in content_type:
     return JsonContext(url, JsonContext.parse(url, content))
   else:
     return HtmlContext(url, HtmlContext.parse(url, content))
@@ -91,16 +93,7 @@ class JsonContext:
     return selected
 
   def text(self):
-    return JsonContext.extract_values(self.json)
-
-  @staticmethod
-  def extract_values(json):
-    if isinstance(json, list):
-      return ' '.join(map(JsonContext.extract_values, json))
-    elif isinstance(json, dict):
-      return ' '.join(map(JsonContext.extract_values, json.values()))
-    else:
-      return json
+    return self.json
 
   def __str__(self):
     return json.dumps(self.json)
